@@ -30,7 +30,7 @@ class Macro:
         self.name = name
 
     def __repr__(self):
-        return 'Macro("%s")' % self.name
+        return f'Macro("{self.name}")'
 
     def __eq__(self, other):
         return self.name == other.name
