@@ -7,12 +7,14 @@ from examples.jsonParser import jsonObject
 from examples.simpleBool import boolExpr
 from examples.simpleSQL import simpleSQL
 from examples.mozillaCalendarParser import calendars
-from pyparsing.diagram import to_railroad, railroad_to_html, NamedDiagram
+from pyparsing.diagram import to_railroad, railroad_to_html, NamedDiagram, AnnotatedItem
 import pyparsing as pp
+import railroad
 import tempfile
 import os
 import sys
 
+
 print(f"Running {__file__}")
 print(sys.version_info)
 
@@ -85,12 +87,12 @@ class TestRailroadDiagrams(unittest.TestCase):
 
     def test_example_rr_diags(self):
         subtests = [
-            (jsonObject, "jsonObject", 8),
-            (boolExpr, "boolExpr", 5),
-            (simpleSQL, "simpleSQL", 20),
-            (calendars, "calendars", 13),
+            ("jsonObject", jsonObject, 8),
+            ("boolExpr", boolExpr, 6),
+            ("simpleSQL", simpleSQL, 20),
+            ("calendars", calendars, 13),
         ]
-        for example_expr, label, expected_rr_len in subtests:
+        for label, example_expr, expected_rr_len in subtests:
             with self.subTest(f"{label}: test rr diag without results names"):
                 railroad = self.generate_railroad(example_expr, example_expr)
                 if len(railroad) != expected_rr_len:
@@ -130,9 +132,9 @@ class TestRailroadDiagrams(unittest.TestCase):
         outer <<= inner
 
         railroad = self.generate_railroad(outer, "inner_only")
-        assert len(railroad) == 2
+        assert len(railroad) == 1
         railroad = self.generate_railroad(outer, "inner_only", show_results_names=True)
-        assert len(railroad) == 2
+        assert len(railroad) == 1
 
     def test_each_grammar(self):
 
@@ -167,11 +169,7 @@ class TestRailroadDiagrams(unittest.TestCase):
     def test_complete_combine_element(self):
         ints = pp.Word(pp.nums)
         grammar = pp.Combine(
-            ints("hours")
-            + pp.Literal(":")
-            + ints("minutes")
-            + pp.Literal(":")
-            + ints("seconds")
+            ints("hours") + ":" + ints("minutes") + ":" + ints("seconds")
         )
         railroad = to_railroad(grammar)
         assert len(railroad) == 1
@@ -181,11 +179,7 @@ class TestRailroadDiagrams(unittest.TestCase):
     def test_create_diagram(self):
         ints = pp.Word(pp.nums)
         grammar = pp.Combine(
-            ints("hours")
-            + pp.Literal(":")
-            + ints("minutes")
-            + pp.Literal(":")
-            + ints("seconds")
+            ints("hours") + ":" + ints("minutes") + ":" + ints("seconds")
         )
 
         diag_strio = StringIO()
@@ -197,11 +191,7 @@ class TestRailroadDiagrams(unittest.TestCase):
     def test_create_diagram_embed(self):
         ints = pp.Word(pp.nums)
         grammar = pp.Combine(
-            ints("hours")
-            + pp.Literal(":")
-            + ints("minutes")
-            + pp.Literal(":")
-            + ints("seconds")
+            ints("hours") + ":" + ints("minutes") + ":" + ints("seconds")
         )
 
         diag_strio = StringIO()
@@ -210,8 +200,24 @@ class TestRailroadDiagrams(unittest.TestCase):
         tags = "<html> </html> <head> </head> <body> </body>".split()
         assert not any(tag in diag_str for tag in tags)
 
+    def test_create_diagram_for_oneormore_with_stopon(self):
+        wd = pp.Word(pp.alphas)
+        grammar = "start" + wd[1, ...:"end"] + "end"
+
+        pp.autoname_elements()
+        railroad_diag = to_railroad(grammar)
+        assert len(railroad_diag) == 3
+        assert isinstance(railroad_diag[1].diagram.items[1].item, railroad.Sequence)
+        assert isinstance(
+            railroad_diag[1].diagram.items[1].item.items[0], AnnotatedItem
+        )
+        assert isinstance(
+            railroad_diag[1].diagram.items[1].item.items[1], railroad.NonTerminal
+        )
+
     def test_kwargs_pass_thru_create_diagram(self):
         from io import StringIO
+
         # Creates a simple diagram with a blue body and
         # various other railroad features colored with
         # a complete disregard for taste
@@ -302,10 +308,11 @@ class TestRailroadDiagrams(unittest.TestCase):
             vertical=6,
             show_results_names=True,
             css=DEFAULT_STYLE,
-            head=expStyle
+            head=expStyle,
         )
 
         self.assertIn(expStyle, diag_html_capture.getvalue())
 
+
 if __name__ == "__main__":
     unittest.main()
